import re
from urllib.parse import urlparse
from .facebook import get_id


def parse_youtube(url):
    o = urlparse(url)
    return o.query.split('=')[1]


def parse_twitter(url):
    url = url.rstrip('/')
    return url.split('/')[-1]


def parse_facebook(url):
    return get_id(url)


def parse_spotify(url):
    o = urlparse(url)
    return o.path.split('/track/')[1]


def parse_instagram(url):
    url = url.rstrip('/')
    return url.split('/')[-1]


def parse_vimeo(url):
    url = url.rstrip('/')
    return url.split('/')[-1]



import re
from urllib.parse import urlparse
import requests


def get_id(url):

    if url[-1] == '/':
        url = url[:-1]

    matches = re.findall('fbid=[\d]+', url)
    if matches:
        fbid = matches[0].split('=')[1]
        return fbid

    resp = requests.get(url)
    matches = re.findall('"entity_id":"[\d]+"', resp.text)
    entity_id = matches[0].split(':')[1].strip('"')
    url_parts = urlparse(url)
    url_path = url_parts.path.rstrip('/')
    fbid = url_path.split('/')[-1]
    return '{}_{}'.format(entity_id, fbid)



from setuptools import setup

long_description = open('README.md').read()

setup(
    name="py-media-id-parser",
    version='0.0.2',
    packages=["media_id_parser"],
    include_package_data=True,
    description="A simple library to return media or post ID's from various social links",
    url="https://github.com/corneliusiv/py-media-id-parser",
    author="Cornelius Hairston",
    author_email="cornelius.hairston@gmail.com",
    license='MIT',
    install_requires=[
        'requests>=2.21.0,<2.22.0',
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    platforms=["any"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
